@@ -35,6 +35,19 @@ class BasicParserTest(util.ParserTest):
         self.parser.aug.save = mock_save
         self.assertRaises(errors.PluginError, self.parser.unsaved_files)
 
+    @mock.patch("certbot_apache._internal.parser.logger")
+    def test_bad_save_errors(self, mock_logger):
+        nx_path = "/non/existent/path.conf"
+        self.parser.aug.set("/augeas/load/Httpd/incl[last()]", nx_path)
+        self.parser.add_dir(f"/files{nx_path}", "AddDirective", "test")
+
+        self.assertRaises(IOError, self.parser.save, {})
+        mock_logger.error.assert_called_with(
+            'Unable to save files: %s.%s', '/non/existent/path.conf', mock.ANY)
+        mock_logger.debug.assert_called_with(
+            "Error %s saving %s: %s", "mk_augtemp",
+            "/non/existent/path.conf", "No such file or directory")
+
     def test_aug_version(self):
         mock_match = mock.Mock(return_value=["something"])
         self.parser.aug.match = mock_match
@@ -42,7 +55,7 @@ class BasicParserTest(util.ParserTest):
         self.assertEqual(self.parser.check_aug_version(),
                          ["something"])
         self.parser.aug.match.side_effect = RuntimeError
-        self.assertFalse(self.parser.check_aug_version())
+        self.assertIs(self.parser.check_aug_version(), False)
 
     def test_find_config_root_no_root(self):
         # pylint: disable=protected-access
@@ -80,8 +93,7 @@ class BasicParserTest(util.ParserTest):
         aug_default = "/files" + self.parser.loc["default"]
         self.parser.add_dir(aug_default, "AddDirective", "test")
 
-        self.assertTrue(
-            self.parser.find_dir("AddDirective", "test", aug_default))
+        self.assertTrue(self.parser.find_dir("AddDirective", "test", aug_default))
 
         self.parser.add_dir(aug_default, "AddList", ["1", "2", "3", "4"])
         matches = self.parser.find_dir("AddList", None, aug_default)
@@ -94,12 +106,9 @@ class BasicParserTest(util.ParserTest):
                                       "AddDirectiveBeginning",
                                       "testBegin")
 
-        self.assertTrue(
-            self.parser.find_dir("AddDirectiveBeginning", "testBegin", aug_default))
+        self.assertTrue(self.parser.find_dir("AddDirectiveBeginning", "testBegin", aug_default))
 
-        self.assertEqual(
-            self.parser.aug.get(aug_default+"/directive[1]"),
-                                "AddDirectiveBeginning")
+        self.assertEqual(self.parser.aug.get(aug_default+"/directive[1]"), "AddDirectiveBeginning")
         self.parser.add_dir_beginning(aug_default, "AddList", ["1", "2", "3", "4"])
         matches = self.parser.find_dir("AddList", None, aug_default)
         for i, match in enumerate(matches):
@@ -108,11 +117,13 @@ class BasicParserTest(util.ParserTest):
         for name in ("empty.conf", "no-directives.conf"):
             conf = "/files" + os.path.join(self.parser.root, "sites-available", name)
             self.parser.add_dir_beginning(conf, "AddDirectiveBeginning", "testBegin")
-            self.assertTrue(self.parser.find_dir("AddDirectiveBeginning", "testBegin", conf))
+            self.assertGreater(
+                len(self.parser.find_dir("AddDirectiveBeginning", "testBegin", conf)),
+                0
+            )
 
     def test_empty_arg(self):
-        self.assertEqual(None,
-                          self.parser.get_arg("/files/whatever/nonexistent"))
+        self.assertIsNone(self.parser.get_arg("/files/whatever/nonexistent"))
 
     def test_add_dir_to_ifmodssl(self):
         """test add_dir_to_ifmodssl.
@@ -131,7 +142,7 @@ class BasicParserTest(util.ParserTest):
         matches = self.parser.find_dir("FakeDirective", "123")
 
         self.assertEqual(len(matches), 1)
-        self.assertTrue("IfModule" in matches[0])
+        self.assertIn("IfModule", matches[0])
 
     def test_add_dir_to_ifmodssl_multiple(self):
         from certbot_apache._internal.parser import get_aug_path
@@ -145,7 +156,7 @@ class BasicParserTest(util.ParserTest):
         matches = self.parser.find_dir("FakeDirective")
 
         self.assertEqual(len(matches), 3)
-        self.assertTrue("IfModule" in matches[0])
+        self.assertIn("IfModule", matches[0])
 
     def test_get_aug_path(self):
         from certbot_apache._internal.parser import get_aug_path
@@ -170,7 +181,7 @@ class BasicParserTest(util.ParserTest):
         with mock.patch("certbot_apache._internal.parser.logger") as mock_logger:
             self.parser.parse_modules()
             # Make sure that we got None return value and logged the file
-            self.assertTrue(mock_logger.debug.called)
+            self.assertIs(mock_logger.debug.called, True)
 
     @mock.patch("certbot_apache._internal.parser.ApacheParser.find_dir")
     @mock.patch("certbot_apache._internal.apache_util._get_runtime_cfg")
@@ -328,7 +339,7 @@ class BasicParserTest(util.ParserTest):
         self.parser.add_comment(get_aug_path(self.parser.loc["name"]), "123456")
         comm = self.parser.find_comments("123456")
         self.assertEqual(len(comm), 1)
-        self.assertTrue(self.parser.loc["name"] in comm[0])
+        self.assertIn(self.parser.loc["name"], comm[0])
 
 
 class ParserInitTest(util.ApacheTest):
@@ -347,8 +358,8 @@ class ParserInitTest(util.ApacheTest):
         self.config.config_test = mock.Mock()
         self.assertRaises(
             errors.NoInstallationError, ApacheParser,
-            os.path.relpath(self.config_path), "/dummy/vhostpath",
-            version=(2, 4, 22), configurator=self.config)
+            os.path.relpath(self.config_path), self.config,
+            "/dummy/vhostpath", version=(2, 4, 22))
 
     def test_init_old_aug(self):
         from certbot_apache._internal.parser import ApacheParser
@@ -356,8 +367,8 @@ class ParserInitTest(util.ApacheTest):
             mock_c.return_value = False
             self.assertRaises(
                 errors.NotSupportedError,
-                ApacheParser, os.path.relpath(self.config_path),
-                "/dummy/vhostpath", version=(2, 4, 22), configurator=self.config)
+                ApacheParser, os.path.relpath(self.config_path), self.config,
+                "/dummy/vhostpath", version=(2, 4, 22))
 
     @mock.patch("certbot_apache._internal.apache_util._get_runtime_cfg")
     def test_unparseable(self, mock_cfg):
@@ -365,8 +376,8 @@ class ParserInitTest(util.ApacheTest):
         mock_cfg.return_value = ('Define: TEST')
         self.assertRaises(
             errors.PluginError,
-            ApacheParser, os.path.relpath(self.config_path),
-            "/dummy/vhostpath", version=(2, 2, 22), configurator=self.config)
+            ApacheParser, os.path.relpath(self.config_path), self.config,
+            "/dummy/vhostpath", version=(2, 2, 22))
 
     def test_root_normalized(self):
         from certbot_apache._internal.parser import ApacheParser
@@ -377,7 +388,7 @@ class ParserInitTest(util.ApacheTest):
                 self.temp_dir,
                 "debian_apache_2_4/////multiple_vhosts/../multiple_vhosts/apache2")
 
-            parser = ApacheParser(path, "/dummy/vhostpath", configurator=self.config)
+            parser = ApacheParser(path, self.config, "/dummy/vhostpath")
 
         self.assertEqual(parser.root, self.config_path)
 
@@ -386,8 +397,7 @@ class ParserInitTest(util.ApacheTest):
         with mock.patch("certbot_apache._internal.parser.ApacheParser."
                         "update_runtime_variables"):
             parser = ApacheParser(
-                os.path.relpath(self.config_path),
-                "/dummy/vhostpath", configurator=self.config)
+                os.path.relpath(self.config_path), self.config, "/dummy/vhostpath")
 
         self.assertEqual(parser.root, self.config_path)
 
@@ -396,8 +406,7 @@ class ParserInitTest(util.ApacheTest):
         with mock.patch("certbot_apache._internal.parser.ApacheParser."
                         "update_runtime_variables"):
             parser = ApacheParser(
-                self.config_path + os.path.sep,
-                "/dummy/vhostpath", configurator=self.config)
+                self.config_path + os.path.sep, self.config, "/dummy/vhostpath")
         self.assertEqual(parser.root, self.config_path)
 
 
